@@ -4,11 +4,11 @@ from functools import wraps
 from ..logging import logs
 
 
-def replace_with_env(d: dict, prefix: str):
+def _replace_with_env(d: dict, prefix: str):
     for k, v in d.items():
         env = f'{prefix}{k.upper().replace("_", "__")}'
         if isinstance(v, dict):
-            replace_with_env(v, f'{env}_')
+            _replace_with_env(v, f'{env}_')
         else:
             if os.getenv(env):
                 d[k] = yaml.safe_load(os.getenv(env))
@@ -26,7 +26,7 @@ def WithEnvConfig(prefix: str = ''):
         def load_env_config(*args, **kwargs):
             conf = func(*args, **kwargs)
             if type(conf) is dict:
-                replace_with_env(conf, prefix)
+                _replace_with_env(conf, prefix)
             else:
                 logs.warning(f'Config type should be dict, but got {type(conf)}') 
             return conf
